#!/bin/bash
# This script is licenced under the GNU General Public Licence version 2 or later

function check_exit_status {
 if [ $? != 0 ]
 then
  echo
  echo "QtWine install script: Failed to install"
  echo
  exit 1
 fi
}

function usage {
echo "QtWine setup script version 1.0"
echo "Usage: $0 [--help|-help|-h]"
echo "       $0 [compile|install]"
echo "       $0 compile install"
echo
echo " --help or -help or -h shows this message."
echo " compile will execute qmake && make"
echo ' install will install qtwine in $INSTALL_DIR'
echo
echo 'If $INSTALL_DIR is not set, the setup script will ask for it'
echo "If you want to install in a directory that you do not have write permissions, you must run this script as root, else it will fail."
echo "If there are no arguments, xterm -e \"$0 compile install\" will be executed"
echo "This way, you don't have to run this script from a terminal"
echo
echo "Usage example:"
echo "INSTALL_DIR=$HOME/bin $0 compile install"
echo "The above line will compile and install qtwine as $HOME/bin/qtwine"
}

function compile {
qmake
check_exit_status
make
check_exit_status
make clean
echo
echo "Qtwine compiled successfully."
echo
}

function install_qtwine {
if [ "$INSTALL_DIR" == "" ];
then
	if [ "$USER" == "root" ];
	then
		rootmode="y"
	else
		rootmode="n"
	fi

	echo
	echo "Where do you want to install qtwine?"
	if [ "$rootmode" == "y" ];
	then
		echo "(Press Enter to use default: /usr/local/bin)"
	else
		echo "(Press Enter to use default: $HOME/bin)"
	fi
	unset INSTALL_DIR
	read INSTALL_DIR
	if [ "$INSTALL_DIR" == "" ];
	then
		if [ "$rootmode" == "y" ];
		then
			INSTALL_DIR="/usr/local/bin"
		else
			INSTALL_DIR="$HOME/bin"
		fi
	fi
fi

if [ ! -e "$INSTALL_DIR" ];
then
	mkdir -p "$INSTALL_DIR"
	check_exit_status
fi

cd bin
install QtWine.bin "$INSTALL_DIR/qtwine"
check_exit_status
echo
echo "Qtwine is now installed."
echo
}

# find_current_directory
scriptName=`basename "$0"`
scriptdir=`dirname "$0"`
currentDir="$PWD"
APP_DIR=""

if [ -e "$PWD/$scriptdir/$scriptName" ]
then
    cd "$PWD/$scriptdir"
    APP_DIR="$PWD"
elif [ -e "$scriptdir/$scriptName" ]
then
    cd "$scriptdir"
    APP_DIR="$PWD"
else
    echo "find_current_dir: Error: Could not find the directory where $scriptName is."
    exit 1
fi

case "$1" in
	"--help"|"-h"|"-help") usage ;;
	"") xterm -e "$0 compile install; sleep 2" ;;
	*) for i in "$@";
	   do
		case $i in
			"compile") compile;;
			"install") install_qtwine;;
		esac
	   done
	   ;;
esac



