/***************************************************************************
 *   Copyright (C) 2006 by George Kiagiadakis   *
 *   gkiagia@users.sourceforge.net   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "version.h"
#include "launcher.h"
#include <QtGui>
#include <QMessageBox>
#include <QString>
#include <QStringList>
#include <QRegExp>
#include <QFileInfo>
#include "winelauncher.h"
#include "createdialog.h"
#include "macros.h"
#include "configdelegate.h"

launcher::launcher(QWidget *parent)
 : QDialog(parent)
{
	lf.setupUi(this);
	cfgHandler->connectListView(lf.cfgList);

	DummyDelegate *delegate = new DummyDelegate;
	lf.cfgList->setItemDelegate( delegate );

	// Load previous session
	lf.terminalBox->setChecked( QtWine::settings->value("launcher/terminal_checkbox_enabled", FALSE).toBool() );

	lf.argsBox->setChecked( QtWine::settings->value("launcher/arguments_checkbox_enabled", FALSE).toBool() );
	lf.argsEdit->setText( QtWine::settings->value("launcher/arguments_lineEdit_text").toString() );

	lf.debugBox->setChecked( QtWine::settings->value("launcher/debug_checkbox_enabled", FALSE).toBool() );
	lf.debugEdit->setText( QtWine::settings->value("launcher/debug_lineEdit_text").toString() );

	lf.logBox->setChecked( QtWine::settings->value("launcher/log_checkbox_enabled", FALSE).toBool() );
	lf.logEdit->setText( QtWine::settings->value("launcher/log_lineEdit_text").toString() );

	// set default to exit qtwine when clicking OK on launcher
	Quit_on_OK = TRUE;
}

launcher::~launcher()
{
	cfgHandler->disconnectListView(lf.cfgList);
}

void launcher::on_OKButton_clicked()
{
	if ( filename.isEmpty() )
	{	qDebug("In function launcher::on_OKButton_clicked(): error: filename is empty."); exit(1);	}

	// READ OPTIONS
	QStringList arguments;
	if ( lf.argsBox->isChecked() )
		arguments << lf.argsEdit->text().split( QRegExp("\\s(?!\"\\w+\\s\\w+\")") );
		// split by spaces but exclude spaces in quotes " "

	QString logFile;
	if ( lf.logBox->isChecked() )
		logFile = lf.logEdit->text();

	QString debugStr;
	if ( lf.debugBox->isChecked() )
		debugStr = lf.debugEdit->text();

	QString workdir = QFileInfo(filename).absolutePath();
	// TODO add lineEdit to change workdir

	// START WINE
	if ( lf.terminalBox->isChecked() )
	{
		saveSession();
		WineLauncher::startTerminal( cfgHandler->getCurrentCfgName(lf.cfgList), filename, arguments, logFile, debugStr, workdir );
		if ( Quit_on_OK )
			exit(0);
	}
	else
	{
		WineLauncher *wine = new WineLauncher;

		wine->setWorkDir( workdir );
		wine->setSilent( TRUE );
		wine->setLogFile( logFile );
		wine->setCfgName(cfgHandler->getCurrentCfgName(lf.cfgList));
		if ( Quit_on_OK )
			wine->setQuitMode( WineLauncher::quit );
		wine->startWine( filename, arguments );
		saveSession();
	}

}

void launcher::on_HelpButton_clicked()
{
	QtWineInformation::about();
}

void launcher::setFileName(QString name)
{
	filename = name;
	setWindowTitle(QString("QtWine launcher - %1").arg(QFileInfo(filename).fileName()));
}

void launcher::setArguments(QString args)
{
	if ( !args.isEmpty() )
	{
		if (!lf.argsBox->isChecked())
			lf.argsBox->setChecked(TRUE);
		lf.argsEdit->setText(args);
	}
}

void launcher::setLog(QString filename)
{
	if ( !filename.isEmpty() )
	{
		if (!lf.logBox->isChecked())
			lf.logBox->setChecked(TRUE);
		lf.logEdit->setText(filename);
	}
}

void launcher::setQuit_on_OK(bool choice)
{
	Quit_on_OK = choice;
// this is to let manager running when launcher is called from manager; see manager::on_action_Run_a_windows_program_triggered()
}

void launcher::saveSession()
{
	QtWine::settings->setValue( "launcher/terminal_checkbox_enabled", lf.terminalBox->isChecked() );
	QtWine::settings->setValue( "launcher/arguments_checkbox_enabled", lf.argsBox->isChecked() );
	QtWine::settings->setValue( "launcher/arguments_lineEdit_text", lf.argsEdit->text() );
	QtWine::settings->setValue( "launcher/debug_checkbox_enabled", lf.debugBox->isChecked() );
	QtWine::settings->setValue( "launcher/debug_lineEdit_text", lf.debugEdit->text() );
	QtWine::settings->setValue( "launcher/log_checkbox_enabled", lf.logBox->isChecked() );
	QtWine::settings->setValue( "launcher/log_lineEdit_text", lf.logEdit->text() );
}

void launcher::on_browseButton_clicked()
{
	lf.logEdit->setText( QFileDialog::getSaveFileName( this, "Choose a log file", "/home" , "Any files (*)" ) );
}

void launcher::on_CreateButton_clicked()
{
	CreateDialog dlg(this);
	dlg.exec();
}

