/***************************************************************************
 *   Copyright (C) 2006 by George Kiagiadakis   *
 *   gkiagia@users.sourceforge.net   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "version.h"

#include <QtGui>
#include <QDialog>
#include <QMainWindow>
#include <QProcess>
#include <QMessageBox>
#include <QInputDialog> 
#include <QString>
#include <QDir>
#include "winelauncher.h"
#include "createdialog.h"
#include "confighandler.h"
#include "manager.h"
#include "optionsdialog.h"
#include "launcher.h"
#include "scriptmaker.h"
#include "macros.h"

manager::manager(QWidget *parent)
	:QMainWindow(parent)
{
	mw.setupUi(this);
	cfgHandler->connectListView(mw.cfgList);

	ConfigDelegate *cfgDelegate = new ConfigDelegate(this);
	mw.cfgList->setItemDelegate(cfgDelegate);

	statusBar()->showMessage("Welcome to QtWine Manager.");

	//connections
	connect(mw.action_About_Qt, SIGNAL(triggered()), qApp, SLOT(aboutQt()) );
}

manager::~manager()
{
	cfgHandler->disconnectListView(mw.cfgList);
}

void manager::on_createButton_clicked()
{
	CreateDialog dlg(this);
	dlg.exec();
}

void manager::on_deleteButton_clicked()
{
	QString cfg = cfgHandler->getCurrentCfgName(mw.cfgList);

	int selection = QMessageBox::question( this, QString("Delete %1").arg(cfg), "Are you sure you want to delete this configuration ?", QMessageBox::Yes, QMessageBox::No );

	if (selection == QMessageBox::Yes)
		cfgHandler->removeCurrentCfg(mw.cfgList);
}

void manager::on_action_Manager_options_triggered()
{
	optionsDialog d(this);
	d.exec();
}

void manager::on_action_Run_a_windows_program_triggered()
{
	QString winApp = QFileDialog::getOpenFileName( this, "Choose a windows executable to execute", "/" , "WINE executables (*.exe *.exe.so)" );

	if (!winApp.isEmpty())
	{
		launcher l;
		l.setFileName(winApp);
		l.setQuit_on_OK(FALSE);
		l.exec();
	}
}

void manager::on_actionCreate_a_launch_script_triggered()
{
	scriptMaker *sm = new scriptMaker(this);
	sm->show(); // not modal
}

void manager::on_actionBrowse_the_scripts_directory_triggered()
{
	QProcess *filebrowser = new QProcess;
	filebrowser->start( QtWine::settings->value("apps/file manager", "konqueror").toString() , QStringList() << QtWine::settings->value("scriptmaker/script_dir", QDir::homePath()+="/bin/").toString() );

	if (!filebrowser->waitForStarted())
	{
		QMessageBox::critical(this,"Error", "Could not open file manager. Check options in manager and try again.", "OK");
	}
}

void manager::launchTool(QString toolName)
{
	if ( mw.actionOpen_tools_in_terminal->isChecked() )
		WineLauncher::startTerminal(cfgHandler->getCurrentCfgName(mw.cfgList), toolName);
	else
	{
		WineLauncher *tool = new WineLauncher;
		tool->setCfgName( cfgHandler->getCurrentCfgName(mw.cfgList) );
		tool->setSilent(TRUE);
		tool->startWine(toolName);
	}
}

void manager::on_cfgButton_clicked() 		{ launchTool( "winecfg" ); }
void manager::on_regButton_clicked() 		{ launchTool( "regedit" ); }
void manager::on_controlButton_clicked() 	{ launchTool( "control" ); }
void manager::on_uninstallButton_clicked() 	{ launchTool( "uninstaller" ); }
void manager::on_taskmanButton_clicked() 	{ launchTool( "taskmgr" ); }
void manager::on_progmanButton_clicked() 	{ launchTool( "progman" ); }
void manager::on_winefileButton_clicked()	{ launchTool( "winefile" ); }
void manager::on_mineButton_clicked() 		{ launchTool( "winemine" ); }
void manager::on_notepadButton_clicked() 	{ launchTool( "notepad" ); }
void manager::on_wordpadButton_clicked() 	{ launchTool( "wordpad" ); }
void manager::on_ieButton_clicked() 		{ launchTool( "iexplore" ); }
void manager::on_clockButton_clicked() 		{ launchTool( "clock" ); }
void manager::on_oleButton_clicked() 		{ launchTool( "oleview" ); }


void manager::on_action_About_qtwine_triggered()
{
	QtWineInformation::about();
}

void manager::on_dosButton_clicked()
{
	WineLauncher::startTerminal(cfgHandler->getCurrentCfgName(mw.cfgList), "cmd");
}

void manager::on_browseButton_clicked()
{
	QProcess *filebrowser = new QProcess;
	filebrowser->start( QtWine::settings->value("apps/file manager", "konqueror").toString() , QStringList() << cfgHandler->getCurrentCfgPath(mw.cfgList) );

	if (!filebrowser->waitForStarted())
	{
		QMessageBox::critical(this,"Error", "Could not open file manager. Check options in manager and try again.", "OK");
	}
}

void manager::on_renameButton_clicked()
{
	mw.cfgList->edit( mw.cfgList->selectionModel()->currentIndex() );
}

