/***************************************************************************
 *   Copyright (C) 2006 by George Kiagiadakis   *
 *   gkiagia@users.sourceforge.net   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "optionsdialog.h"
#include "confighandler.h"
#include <QFileDialog>
#include <QMessageBox>
#include <QString>
#include "macros.h"

optionsDialog::optionsDialog(QWidget *parent)
 : QDialog(parent)
{
	dlg.setupUi(this);
	dlg.fmEdit->setText( QtWine::settings->value("apps/file manager", "konqueror").toString() );
	dlg.termEdit->setText( QtWine::settings->value("apps/terminal", "konsole").toString() );
	dlg.cfgDirEdit->setText( QtWine::settings->value("general/config_dir", DEFAULT_CONFIG_PATH).toString() );
	dlg.scriptDirEdit->setText( QtWine::settings->value("scriptmaker/script_dir", QDir::homePath()+="/bin/").toString() );
	dlg.useDotWineCheckBox->setChecked( QtWine::settings->value("general/use_wine_default_cfg", TRUE).toBool() );
	connect( dlg.okButton, SIGNAL(clicked()), this, SLOT(save()) );
}

optionsDialog::~optionsDialog()
{
}

void optionsDialog::save()  // and close :-)
{
	QtWine::settings->setValue("general/use_wine_default_cfg", dlg.useDotWineCheckBox->isChecked());
	QtWine::settings->setValue("apps/file manager", dlg.fmEdit->text());
	QtWine::settings->setValue("apps/terminal", dlg.termEdit->text());

	if ( !dlg.cfgDirEdit->text().endsWith("/") )
		dlg.cfgDirEdit->setText( dlg.cfgDirEdit->text() += "/" ); // cfg dir must end with a slash
	if ( !dlg.scriptDirEdit->text().endsWith("/") )
		dlg.scriptDirEdit->setText( dlg.scriptDirEdit->text() += "/" ); // script dir too

	QtWine::settings->setValue("scriptmaker/script_dir", dlg.scriptDirEdit->text());

	if ( cfgHandler != NULL ) // might be null if qtwine runs with --options
		cfgHandler->changeCfgDir( dlg.cfgDirEdit->text() ); // this also handles "general/use_wine_default_cfg"

	done(QDialog::Accepted); // close dialog
}

void optionsDialog::on_browseScriptDirButton_clicked()
{
	QString s = QFileDialog::getExistingDirectory( this, "Select the directory to place the scripts", QDir::homePath(), QFileDialog::ShowDirsOnly);
	if ( !s.isEmpty() )
		dlg.scriptDirEdit->setText( s );
}

void optionsDialog::on_browseCfgDirButton_clicked()
{
	QString s = QFileDialog::getExistingDirectory( this, "Select the directory to place the wine configurations", QDir::homePath(), QFileDialog::ShowDirsOnly);
	if ( !s.isEmpty() )
		dlg.cfgDirEdit->setText( s );
}

